#!/bin/sh

NAME=install.sh
VERSION=0.13
SCRIPT=$(readlink -f $0)
SCRIPT_PATH=`dirname $SCRIPT`

TEMP_DIR=/tmp/skyhub
CONF_DIR=/etc/skyhub
WIFI_CONF=/etc/hostapd_wlan0.conf

SERIAL_FILE=$CONF_DIR/serial_number
SERIAL_HELP="Run './install.sh --serial 123456' to set the serial number"
DEFAULT_SERIAL=000000

cd "$(dirname "$(readlink -f "${0}")")"

# Parse arguments
while [[ "$#" -gt 0 ]]
do
    key="$1"

    case $key in
        --serial)
        serial="$2"
        shift
        shift
        ;;
        -h|--help)
        HELP=YES
        shift
        ;;
        --version)
        SHOW_VERSION=YES
        shift
        ;;
        *)
        shift
        ;;
    esac
done

display_help() {
    echo "Usage: $NAME [OPTION]..."
    echo
    echo "OPTIONs:"
    echo
    echo "  --serial SERIAL  set serial number to SERIAL"
    echo "                   (SERIAL must be in 123456 format)"
    echo "  -h, --help       display this help message"
    echo "  --version        show version info"
    echo
    echo "Usage:"
    echo
    echo "$NAME"
    echo "$NAME --serial 0123456"
    echo "$NAME --version"
    echo
}

if [ -v SHOW_VERSION ] ; then
    echo "$NAME $VERSION"
    exit 0
fi

if [ -v HELP ] ; then
    display_help
    exit 0
fi

# Enable Wi-Fi
nmcli radio wifi on

# Copy configuration files to a temp directory
mkdir -p $TEMP_DIR
if [ -d $CONF_DIR/ ]; then
	cp -r $CONF_DIR/* $TEMP_DIR/
fi

# Uninstall 
$SCRIPT_PATH/uninstall.sh

# Create directories
mkdir -p $CONF_DIR

# Restore configuration files and erase a temp directory
mv $TEMP_DIR/* $CONF_DIR/
rm -rf $TEMP_DIR

# Copy software
cp -vfr usr/ /
ldconfig /usr/local/lib/
ldconfig /usr/local/lib/skyhub

cp -vfr etc/ /
update-rc.d skyhub defaults 98
update-rc.d skyhubsrv defaults 99

echo -e "[Paths]\nPrefix=/usr/local/bin" > /usr/local/bin/qt.conf

#Insert ftdi_sio 
cat /proc/modules | grep ftdi_sio
if [ $(echo $?) != 0 ] ; then
    cp -vfr lib/ /
    insmod /lib/modules/4.14.133-dey+g8aed12dc111b/kernel/drivers/usb/serial/ftdi_sio.ko
    depmod
fi

#Insert ch341.ko
cat /proc/modules | grep ch341
if [ $(echo $?) != 0 ] ; then
    cp -vfr lib/ /
    insmod /lib/modules/4.14.133-dey+g8aed12dc111b/kernel/drivers/usb/serial/ch341.ko
    depmod
fi

# Set serial number
SHOULD_UPDATE=true

if [ ! -f $SERIAL_FILE ] ; then
    echo "Serial number file doesn't exist."
    echo $SERIAL_HELP
else
    if ! [ -v serial ] ; then
        serial=$(head -n 1 $SERIAL_FILE)
        if [ "$serial" = $DEFAULT_SERIAL ]; then
            echo $SERIAL_HELP
        fi
    fi
fi

while [ "$SHOULD_UPDATE" = true ]; do
    if ! [ -v serial ] ; then
        serial=$DEFAULT_SERIAL
    fi
    if [[ "$serial" =~ ^[0-9]{6}$ ]] ; then
        echo $serial > $SERIAL_FILE
        sed -i "s/ssid=.*/ssid=UgCS-SkyHub-$serial/" $WIFI_CONF

        SHOULD_UPDATE=false
    else
        echo "Invalid serial number \"$serial\""
        read -r -p "Please, enter serial number as 123456: " serial
    fi
done

sync

# Start new software
/etc/init.d/skyhub start
/etc/init.d/skyhubsrv start
